pub struct CreateLayout {
pub name: String,
pub symbol: String,
pub uri: String,
}Fields
name: Stringsymbol: Stringuri: StringTrait Implementations
Sourceimpl BorshDeserialize for CreateLayoutwhere
String: BorshDeserialize,
impl BorshDeserialize for CreateLayoutwhere
String: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for CreateLayoutwhere
String: BorshSerialize,
impl BorshSerialize for CreateLayoutwhere
String: BorshSerialize,
Sourceimpl Clone for CreateLayout
impl Clone for CreateLayout
Sourcefn clone(&self) -> CreateLayout
fn clone(&self) -> CreateLayout
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for CreateLayout
impl RefUnwindSafe for CreateLayout
impl Send for CreateLayout
impl Sync for CreateLayout
impl Unpin for CreateLayout
impl UnwindSafe for CreateLayout